==> KleckFiles(5.115.00).zip: KleckFiles/wiki/wikiTOC.js <==
// Wiki TOCs

// filename | label
// files are located in 'wiki/page/{pageid}.js'

var _wiki_extras = {
	redirects : [
		// 'radio' redirects to ...
		'radio|kf|history_2012|History 2012'
	],
	isRedirect : function(pageId) {
		var i;
		for (i = 0; i < this.redirects.length; i++) {
			if (this.redirects[i].startsWith(pageId + '|'))
				return this.redirects[i].split('|');	 
		}
		result = null;
	},
	Redirect : function(pageId) {
		var rd = this.isRedirect(pageId);
		if (rd != null && rd.length > 2)
			return rd[2];
		else 
			return pageId;
	},
	
	
	// Retrieve a TOC _wiki_list_.. data from below 
	getBookTOC : function(bidx) {  // _wiki_extras.getBookTOC(bookId)
		// default	
		var rec = {toc: _wiki_list, bidx:-1};  
		
		if (bidx >= 0 && bidx < __wikiGlobals.books.length) 
		{
			rec.bidx = bidx;
			var id = __wikiGlobals.books[bidx].id.toUpperCase();
			
			if (id == "KF") rec.toc = _wiki_list_KF;
			else if (id == "DS") rec.toc = _wiki_list_DS;
			else if (id == "MU") rec.toc = _wiki_list_MU;
			else if (id == "BN") rec.toc = _wiki_list_BN;
			else if (id == "NB") rec.toc = _wiki_list_NB;
			else if (id == "PL") rec.toc = _wiki_list_PL;	
			else if (id == "TEST") rec.toc = _wiki_list_TEST;	
			else 
				rec.bidx = -1;
		}
		return rec;
	}
	
}


var _wiki_list_TEST = [	// Test
	[
	]
];	

var _wiki_list_BN = [	// Breaking News
		[// (0) is main TOC
			'(toc)/Breaking News',
		 	//'Pages', // optional section
			'home | Home',  // file id + display text

			''
		]
];
	
var _wiki_list_PL = [	// Project Logos 
		[// (0) is main TOC
			'(toc)/Project Logos',
		 	//'Pages', // optional section
			'home | Home',  // file id + display text
		 	'cmdline | Command-line',
			'codePage | Special code',

			''
		]
];
	
var _wiki_list_DS = [	// Dave Shadow 
		[// (0) is main TOC
			'(toc)/Dave Shadow',
		 	//'Pages', // optional section
			'home | Home',  // file id + display text
			'best | Best Clips',
			''
		]
];

var _wiki_list_MU = [	// Music 
		[// (0) is main TOC
			'(toc)/Music',
		 	//'Pages', // optional section
			'home | Home',  // file id + display text
			' youreagod | 🎹 You\'re a God',
			' whilemyg | 🎹 While my guitar gently weeps',
			' chains | 🎹 The Chain',
			' youresovain | 🎹 You\'re so Vain',
			' windbeneathmywings | 🎹 Wind Beneath my Wings',
			' cannonball | 🎹 Cannonball',
			' aroundtheworld | 🎹 Around the World',
			''
		]
];
	
var _wiki_list_NB = [	// Note Book
	[// (0) is main TOC
		'(toc)/Notebook',
		//'Pages', // optional section
		'home | Home',  // file id + display text
		'bible | Bible', 
		'bible2 | Bible 2', 
//		'(mov) | Movies',
//		'(robert) | Robert',
		''
	],
	[
		'(robert)/Robert', // first item = ListID/ListName
		'robert | Testimony', 
		'facebook | Facebook', 
		''
	],
	[
		'(mov)/Movies',
		'movies | Movies',
		'm_startrekOrig | Star Trek : Original',
		'm_readyPlayerOne | Ready Player One (2018)',
		''
	]
];
	
var _wiki_list_KF = [   // KleckFiles
	[ // (0) is main TOC
	'(toc)/Kleck Wiki', // item 1 = ListID/Title = always first item
	'home | 🏡 Home',  // file id + display text	
	'Jonathan Kleck',  // section title 🧸 
	'testimony | 🔔 Testimony',
	'(moreVideos) | 🎬 Videos',
	'(dvds) | 📀 DVDs',
	'radio | 📻 Radio',       // 'radio' redirect
	'jkclips | 📽 JK Clips',
	'jkimages | 🎭 Image Gallery',
		
	'Resources', // section title 📌 
	'(history) | 🚀 History',
	'kjv+strongs | 💡 KJV+ Strongs',
	'captions | <span class="ccStyle1">cc</span> Closed Captions', //❝
	'info.html | ❔ Help / Official JK sites',
	''
	],
	[ 
	'(moreVideos)/🎬 Videos', // List ID/ListTitle/show 5 items only
	//'More Videos/xxmore:4',   // section title - 4th item = more...
	'shorts | Shorts',
	'230807-01 | Jesus is El <span class="mnuDim">(8:23)</span>',
	'230806-01 | The Serpents World <span class="mnuDim">(4:11)</span>',
	'230730 | Bible UNLOCKED <span class="mnuDim">(8:30)</span>',
	'140809 | 911 The Temple <span class="mnuDim">(10:47)</span>',
	'130823-02 | The Red Cleansing <span class="mnuDim">(4:40)</span>',
	'211202 | A Twin System <span class="mnuDim">(16:17+)</span>',
	'171022 | System of Control <span class="mnuDim">(11:31)</span>',
	'vatican | The Vatican',
	'symbols | Sight &amp Symbols',
	'kleckFavs | My Favorites',
	''
	],
	[
		'(dvds)/📀 DVDs', 
		'dvd_1 | A Kingdom Divided',
		'dvd_2 | Queen of Heaven',
		'dvd_3 | The Destruction of America',
		'dvd_4 | Be 4 The Fire',
		'dvd_5 | BarAkhenaten',
		'dvd_6 | Crowning the Tyrant',
		'dvd_7 | Breath of Life',
		'dvd_8 | You are Exiles',
	   ''
	],
	[
		'(history)/🚀 History', 
		'history_2002 | History 2002',
		'history_2012 | History 2012',
		'history_2019 | History 2019',
		'history_2020 | History 2020',
		'history_2021 | History 2021',
		'history_2022 | History 2022',
		'history_2023 | History 2023 (1)',
		'history_2023_part2 | History 2023 (2)',
	   ''
	]
	
];

==> KleckFiles(6.39.00).zip: KleckFiles/wiki/wikiTOC.js <==
// Wiki TOCs

// filename | label
// files are located in 'wiki/page/{pageid}.js'

var _wiki_extras = {
	redirects : [
		// 'radio' redirects to ...
		'radio|kf|history_2012|History 2012'
	],
	isRedirect : function(pageId) {
		var i;
		for (i = 0; i < this.redirects.length; i++) {
			if (this.redirects[i].startsWith(pageId + '|'))
				return this.redirects[i].split('|');	 
		}
		result = null;
	},
	Redirect : function(pageId) {
		var rd = this.isRedirect(pageId);
		if (rd != null && rd.length > 2)
			return rd[2];
		else 
			return pageId;
	},
	
	
	// Retrieve a TOC _wiki_list_.. data from below 
	getBookTOC : function(bidx) {  // _wiki_extras.getBookTOC(bookId)
		// default	
		var rec = {toc: _wiki_list, bidx:-1};  
		
		if (bidx >= 0 && bidx < __wikiGlobals.books.length) 
		{
			rec.bidx = bidx;
			var id = __wikiGlobals.books[bidx].id.toUpperCase();
			
			if (id == "KF") rec.toc = _wiki_list_KF;
			else if (id == "DS") rec.toc = _wiki_list_DS;
			else if (id == "MU") rec.toc = _wiki_list_MU;
			else if (id == "BN") rec.toc = _wiki_list_BN;
			else if (id == "NB") rec.toc = _wiki_list_NB;
			else if (id == "PL") rec.toc = _wiki_list_PL;	
			else if (id == "TEST") rec.toc = _wiki_list_TEST;	
			else 
				rec.bidx = -1;
		}
		return rec;
	}
	
}


var _wiki_list_TEST = [	// Test
	[
	]
];	

var _wiki_list_BN = [	// Breaking News
		[// (0) is main TOC
			'(toc)/Breaking News',
		 	//'Pages', // optional section
			'home | Home',  // file id + display text

			''
		]
];
	
var _wiki_list_PL = [	// Project Logos 
		[// (0) is main TOC
			'(toc)/Project Logos',
		 	//'Pages', // optional section
			'home | Home',  // file id + display text
		 	'cmdline | Command-line',
			'codePage | Special code',

			''
		]
];
	
var _wiki_list_DS = [	// Dave Shadow 
		[// (0) is main TOC
			'(toc)/Dave Shadow',
		 	//'Pages', // optional section
			'home | Home',  // file id + display text
			'best | Best Clips',
			''
		]
];

var _wiki_list_MU = [	// Music 
		[// (0) is main TOC
			'(toc)/Music',
		 	//'Pages', // optional section
			'home | Home',  // file id + display text
			' youreagod | 🎹 You\'re a God',
			' whilemyg | 🎹 While my guitar gently weeps',
			' chains | 🎹 The Chain',
			' youresovain | 🎹 You\'re so Vain',
			' windbeneathmywings | 🎹 Wind Beneath my Wings',
			' cannonball | 🎹 Cannonball',
			' aroundtheworld | 🎹 Around the World',
			''
		]
];
	
var _wiki_list_NB = [	// Note Book
	[// (0) is main TOC
		'(toc)/Notebook',
		//'Pages', // optional section
		'home | Home',  // file id + display text
		'bible | Bible', 
		'bible2 | Bible 2', 
		
//		'(mov) | Movies',
//		'(robert) | Robert',
		''
	],
	[
		'(robert)/Robert', // first item = ListID/ListName
		'robert | Testimony', 
		'facebook | Facebook', 
		''
	],
	[
		'(mov)/Movies',
		'movies | Movies',
		'm_startrekOrig | Star Trek : Original',
		'm_readyPlayerOne | Ready Player One (2018)',
		''
	]
];
	
var _wiki_list_KF = [   // KleckFiles
	[ // (0) is main TOC
	'(toc)/Kleck Wiki', // item 1 = ListID/Title = always first item
	'home | 🏡 Home',  // file id + display text	
	'tags | <span style="font-size:130%;margin:0px 5px;">#</span> Keywords', // ♯
	'Jonathan Kleck',  // section title 🧸 
	'testimony | 🔔 Testimony',
	'(moreVideos) | 🎬 Videos',
	'(dvds) | 📀 DVDs',
	'radio | 📻 Radio',       // 'radio' redirect
	'jkclips | 📽 JK Clips',
	'jkimages | 🎭 Image Gallery',
		
	'Resources', // section title 📌 
	'(history) | 🚀 History',
	'kjv+strongs | 💡 KJV+ Strongs',
	'captions | <span class="ccStyle1">cc</span> Closed Captions', //❝
	'info.html | ❔ Help / Official JK sites',
	''
	],
	[ 
	'(moreVideos)/🎬 Videos', // List ID/ListTitle/show 5 items only
	//'More Videos/xxmore:4',   // section title - 4th item = more...
	'shorts | Shorts',
	'230807-01 | Jesus is El <span class="mnuDim">(8:23)</span>',
	'230806-01 | The Serpents World <span class="mnuDim">(4:11)</span>',
	'230730 | Bible UNLOCKED <span class="mnuDim">(8:30)</span>',
	'140809 | 911 The Temple <span class="mnuDim">(10:47)</span>',
	'130823-02 | The Red Cleansing <span class="mnuDim">(4:40)</span>',
	'211202 | A Twin System <span class="mnuDim">(16:17+)</span>',
	'171022 | System of Control <span class="mnuDim">(11:31)</span>',
	'vatican | The Vatican',
	'symbols | Sight &amp Symbols',
	'kleckFavs | My Favorites',
	''
	],
	[
		'(dvds)/📀 DVDs', 
		'dvd_1 | A Kingdom Divided',
		'dvd_2 | Queen of Heaven',
		'dvd_3 | The Destruction of America',
		'dvd_4 | Be 4 The Fire',
		'dvd_5 | BarAkhenaten',
		'dvd_6 | Crowning the Tyrant',
		'dvd_7 | Breath of Life',
		'dvd_8 | You are Exiles',
	   ''
	],
	[
		'(history)/🚀 History', 
		'history_2002 | History 2002',
		'history_2012 | History 2012',
		'history_2019 | History 2019',
		'history_2020 | History 2020',
		'history_2021 | History 2021',
		'history_2022 | History 2022',
		'history_2023 | History 2023',
		'history_2024 | History 2024',
	   ''
	]
	
];
